@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use smallnum;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 our %TOOL;
 
@@ -325,7 +325,7 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
@@ -342,7 +342,8 @@ Version 0.17
 	$black->toHSL # hsl(0,0%,0%)
 	$black->toHSV # hsv(0,0%,0%)
 	$black->toTerm # r0g0b0
-
+	$black->toOnTerm # on_r0g0b0
+	
 	my $white = $black->lighten('100%');
 	my $black = $white->darken('100%');
 
@@ -497,6 +498,20 @@ Returns an opaque colour string from hue, saturation and value (HSV) values.
 
 =cut
 
+=head2 toTerm
+
+Returns an opaque colour string from decimal red, green and blue (RGB) values 
+valid for Term::ANSIColor foreground content.
+
+	my $string = $colour->toCSS;
+
+=head2 toOnTerm
+
+Returns an opaque colour string from decimal red, green and blue (RGB) values 
+valid for Term::ANSIColor background content.
+
+	my $string = $colour->toCSS;
+
 =head2 colour
 
 Returns an array containeing the red, green and blue (RGB) values.
